summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/browser_window.h
diff options
context:
space:
mode:
authorjered@chromium.org <jered@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-09-20 00:48:47 +0000
committerjered@chromium.org <jered@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-09-20 00:48:47 +0000
commitb0628ad0bd4ddc6c34d0f4edfd32aa74ba4821ab (patch)
treea324b758bbacfa51dd346dc71defe9093999f49d /chrome/browser/ui/browser_window.h
parent7c86ceecc6375b6d7560f7f247a1586e6ff71779 (diff)
downloadchromium_src-b0628ad0bd4ddc6c34d0f4edfd32aa74ba4821ab.zip
chromium_src-b0628ad0bd4ddc6c34d0f4edfd32aa74ba4821ab.tar.gz
chromium_src-b0628ad0bd4ddc6c34d0f4edfd32aa74ba4821ab.tar.bz2
Hook up SetInstantPreviewHeight for ChromeOS.
I tested this by specifying the fake instant page with --instant-url and adding some calls to setNonNativeDropdownHeight(). BUG= Review URL: https://chromiumcodereview.appspot.com/10915217 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@157670 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/browser_window.h')
-rw-r--r--chrome/browser/ui/browser_window.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/chrome/browser/ui/browser_window.h b/chrome/browser/ui/browser_window.h
index efa96ca..d0ab1ba 100644
--- a/chrome/browser/ui/browser_window.h
+++ b/chrome/browser/ui/browser_window.h
@@ -12,6 +12,7 @@
#include "chrome/browser/ui/fullscreen/fullscreen_exit_bubble_type.h"
#include "chrome/browser/ui/sync/one_click_signin_sync_starter.h"
#include "chrome/common/content_settings_types.h"
+#include "chrome/common/instant_types.h"
#include "ui/gfx/native_widget_types.h"
#include "webkit/glue/window_open_disposition.h"
@@ -323,10 +324,12 @@ class BrowserWindow : public BaseWindow {
virtual bool InPresentationMode() = 0;
#endif
- // Invoked when instant's tab contents should be shown.
- virtual void ShowInstant(TabContents* preview) = 0;
+ // Invoked when instant's tab contents should be shown with given |height|.
+ virtual void ShowInstant(TabContents* preview,
+ int height,
+ InstantSizeUnits units) = 0;
- // Invoked when the instant's tab contents should be hidden.
+ // Invoked when instant's tab contents should be hidden.
virtual void HideInstant() = 0;
// Returns the desired bounds for instant in screen coordinates. Note that if